@@ -179,5 +179,15 @@ typedef enum
 #endif
 
 
+#ifndef __Have_stricmp
+ #ifdef __Have_strcasecmp
+  #define stricmp strcasecmp
+  #define strnicmp strncasecmp
+ #endif
+ #ifndef stricmp        //already fixed?
+  #define stricmp strcmp
+ #endif
+#endif
+
 
 #endif
