@@ -6,7 +6,13 @@
  *		after compiling this module.				      *
  * licency:     GPL		                                              *
  ******************************************************************************/
-#include "cplib.cc"
+#include <stdlib.h>
+
+#include <stringa.h>
+#include <dbllist.h>
+
+#include "cplib.h"
+
 
 #if !defined(__DJGPP__)
 #include "../jobs/csext.h"
@@ -482,6 +488,28 @@ return 0;
 }
 
 
+static int BuildTranslator(const codepage & cp1, const codepage & cp2, FILE *F)
+{
+Translator trn;
+
+ printf("Info: translator %s -> %s",cp1.name,cp2.name);
+ if(CreateTranslator(trn,cp1,cp2) < 0)
+ {
+   printf(" failure\n");
+   return -1;
+ }
+ printf(" built");
+ if(WriteTranslator(cp1,cp2,trn,F) < 0)
+ {
+   printf(" failure\n");
+   return -2;
+ }
+ printf("; written on disk\n");
+ return 0;
+}
+
+
+
 int main(int argc, char *argv[])
 {
 FILE *F;
@@ -494,7 +522,7 @@ codepage cp852, cp1250, cp1251, cp1252, cp1253, cp1254, cp1255, cp1276, cpkam,
          MAC_ROMAN;
 codepage cphtml;
 codepage symbol, Wingdings;
-Translator trn;
+//Translator trn;
 doublelist llHTML;
 string FileName;
 
@@ -505,6 +533,7 @@ string FileName;
    int i = 0;
    while(++i < argc)
      {
+     //printf("i=%d, argc=%d\n",i,argc);
      if(!strcmp(argv[i],"-dir"))
 	{
 	i++;
@@ -597,17 +626,10 @@ string FileName;
  fprintf(F,"/*Do not edit this file, it is generated automatically from .enc files*/\n");
 
 
- CreateTranslator(trn,cpwp4a, internal);
- WriteTranslator(cpwp4a,internal,trn,F);
-
- CreateTranslator(trn,cpwp5, internal);
- WriteTranslator(cpwp5,internal,trn,F);
-
- CreateTranslator(trn,cpwp5_cz, internal);
- WriteTranslator(cpwp5_cz,internal,trn,F);
-
- CreateTranslator(trn,cpwp6, internal);
- WriteTranslator(cpwp6,internal,trn,F);
+ BuildTranslator(cpwp4a,internal,F);
+ BuildTranslator(cpwp5,internal,F);
+ BuildTranslator(cpwp5_cz,internal,F);
+ BuildTranslator(cpwp6,internal,F);
 
 //if(heapcheck()<=0)
 //	asm int 3;
@@ -641,8 +663,7 @@ WriteTranslator(cp1250,cpkam,trn,F);
    return -3;
  }
  fprintf(F,"/*Do not edit this file. It is automatically generated.*/\n");
- CreateTranslator(trn,cphtml, internal);
- WriteTranslator(cphtml,internal,trn,F);
+ BuildTranslator(cphtml,internal,F);
  WriteStringTable(F,cphtml,llHTML);
  if(FcloseEpilog(F,FileName(),"html.trn")) return -1;
 
@@ -654,60 +675,28 @@ WriteTranslator(cp1250,cpkam,trn,F);
    return -2;
  }
  fprintf(F,"/*Do not edit this file. It is automatically generated.*/\n");
- CreateTranslator(trn,cpkam,internal);
- WriteTranslator(cpkam,internal,trn,F);
+ BuildTranslator(cpkam,internal,F);
 
- CreateTranslator(trn,iso_8859_1,internal);
- WriteTranslator(iso_8859_1,internal,trn,F);
+ BuildTranslator(iso_8859_1,internal,F);
+ BuildTranslator(iso_8859_2,internal,F);
+ BuildTranslator(iso_8859_3,internal,F);
+ BuildTranslator(iso_8859_4,internal,F);
 
- CreateTranslator(trn,iso_8859_2,internal);
- WriteTranslator(iso_8859_2,internal,trn,F);
-
- CreateTranslator(trn,iso_8859_3,internal);
- WriteTranslator(iso_8859_3,internal,trn,F);
-
- CreateTranslator(trn,iso_8859_4,internal);
- WriteTranslator(iso_8859_4,internal,trn,F);
-
- CreateTranslator(trn,cp852,internal);
- WriteTranslator(cp852,internal,trn,F);
-
- CreateTranslator(trn,cp1250,internal);
- WriteTranslator(cp1250,internal,trn,F);
-
- CreateTranslator(trn,cp1251,internal);
- WriteTranslator(cp1251,internal,trn,F);
-
- CreateTranslator(trn,cp1252,internal);
- WriteTranslator(cp1252,internal,trn,F);
-
- CreateTranslator(trn,cp1253,internal);
- WriteTranslator(cp1253,internal,trn,F);
-
- CreateTranslator(trn,cp1254,internal);
- WriteTranslator(cp1254,internal,trn,F);
-
- CreateTranslator(trn,cp1255,internal);
- WriteTranslator(cp1255,internal,trn,F);
-
- CreateTranslator(trn,unicode,internal);
- WriteTranslator(unicode,internal,trn,F);
-
- CreateTranslator(trn,koi8cs,internal);
- WriteTranslator(koi8cs,internal,trn,F);
-
- CreateTranslator(trn,koi8r,internal);
- WriteTranslator(koi8r,internal,trn,F);
+ BuildTranslator(cp852,internal,F);
+ BuildTranslator(cp1250,internal,F);
+ BuildTranslator(cp1251,internal,F);
+ BuildTranslator(cp1252,internal,F);
+ BuildTranslator(cp1253,internal,F);
+ BuildTranslator(cp1254,internal,F);
+ BuildTranslator(cp1255,internal,F);
+ BuildTranslator(unicode,internal,F);
+ BuildTranslator(koi8cs,internal,F);
+ BuildTranslator(koi8r,internal,F);
 
 	// *************** Output codepage generator *****************
- CreateTranslator(trn, internal, unicode);
- WriteTranslator(internal, unicode, trn, F);
-
- CreateTranslator(trn, internal, cp1276);
- WriteTranslator(internal, cp1276, trn, F);
-
- CreateTranslator(trn, internal, symbol);
- WriteTranslator(internal, symbol, trn, F);
+ BuildTranslator(internal,unicode, F);
+ BuildTranslator(internal,cp1276, F);
+ BuildTranslator(internal,symbol, F);
 
 /*
  CreateTranslator(trn, internal, cp1250);
@@ -733,14 +722,10 @@ WriteTranslator(cp1250,cpkam,trn,F);
  }
 
  fprintf(F,"/*Do not edit this file. It is automatically generated.*/\n");
- CreateTranslator(trn, symbol, internal);
- WriteTranslator(symbol, internal, trn, F);
+ BuildTranslator(symbol, internal, F);
+ BuildTranslator(Wingdings, internal, F);
+ BuildTranslator(mtef2, internal, F);
 
- CreateTranslator(trn, Wingdings, internal);
- WriteTranslator(Wingdings, internal, trn, F);
-
- CreateTranslator(trn, mtef2, internal);
- WriteTranslator(mtef2, internal, trn, F);
  if(FcloseEpilog(F,FileName(),"mtef.trn")) return -1;
 
 
@@ -752,13 +737,10 @@ SkipMtef:
    return -3;
  }
  fprintf(F,"/*Do not edit this file. It is automatically generated.*/\n");
- CreateTranslator(trn,MAC_ROMAN,internal);
- WriteTranslator(MAC_ROMAN,internal,trn,F);
+ BuildTranslator(MAC_ROMAN,internal,F);
  if(FcloseEpilog(F,FileName(),"macroman.trn")) return -1;
 
 
- trn.erase();
-
 #if !defined(__DJGPP__)
  if(Flock)
  {
