@@ -2,16 +2,19 @@
 #include <stdlib.h>
 //#include <alloc.h>
 #include <string.h>
-//#include <mem.h>
 
-#include "typedfs.h"
 #include <stringa.h>
 #include <dbllist.h>
 
-#ifndef coreleft
-  #define coreleft() 0l
+#include "cplib.h"
+
+#if defined(__BORLANDC__) && !defined(__WIN32__)
+ #include "cp_lib/cptran.h"
+#else
+ #include "cptran.h"
 #endif
 
+
 #ifndef setmem
 void setmem(void *buff,int count,char number)
 {
@@ -48,33 +51,6 @@ return(PathName);
 }
 
 
-class codepage
-	{
-public: codepage(void)	{name=NULL;characters=NULL;MaxUsed=Allocated=0;};
-	~codepage(void)	{free(name);free(characters);Allocated=0;};
-
-	char *name;
-	WORD Allocated;
-	WORD MaxUsed;
-	char **characters;
-
-	void InsertCharDesc(WORD position, const char *Name);
-	};
-
-
-class Translator
-	{
-public: Translator(void)  {ToCp=FromCp=NULL;Data=NULL;}
-	~Translator(void) {if(Data!=NULL) {free(Data);Data=NULL;}}
-
-	const codepage *FromCp;
-	const codepage *ToCp;
-	WORD *Data;
-
-	void erase(void) {if(Data!=NULL) {free(Data);Data=NULL;}ToCp=FromCp=NULL;}
-	};
-
-
 void codepage::InsertCharDesc(WORD position, const char *Name)
 {
 if(Name==NULL) return;
@@ -193,17 +169,16 @@ cp.InsertCharDesc(number,text);
 }
 
 
-void CreateTranslator(Translator & trn, const codepage & cp1, const codepage & cp2)
+int CreateTranslator(Translator & trn, const codepage & cp1, const codepage & cp2)
 {
 WORD i,j;
 
 trn.erase();
-printf("Info: Building translator %s -> %s\n",cp1.name,cp2.name);
 
 if((trn.Data=(WORD *)calloc(cp1.MaxUsed,sizeof(WORD)))==NULL) 
   {
   printf(" >>Memory exhausted!");
-  return;
+  return -1;
   }
 //setmem(trn.Data,cp1.MaxUsed,0); - calloc initialises memory.
 
@@ -218,22 +193,24 @@ for(i=0;i<cp1.MaxUsed;i++)
 	if(cp2.characters[j]==NULL) continue;
 	if(!strcmp(cp1.characters[i],cp2.characters[j]))
 		{
+// This memory optimisation causes problem during deallocating
 		if(cp1.characters[i]!=cp2.characters[j])
 			{
 			free(cp1.characters[i]);	//optimize memory
 			cp1.characters[i]=cp2.characters[j];
 			}
-		trn.Data[i]=j;
+// ~~~~~
+		trn.Data[i] = j;
 		break;
 		}
 	}
     }
 
-return;
+return 0;
 }
 
 
-bool LoadCodePage(string cpfilename, codepage & cp, int ShowAll=1)
+bool LoadCodePage(string cpfilename, codepage & cp, int ShowAll)
 {
 FILE *Fcp;
 
@@ -362,27 +339,27 @@ return 256*(BanksTotal-EmptyBankCount) + 4*BanksTotal;
 
 
 /*This procedure stores translator file to the disk*/
-void WriteTranslator(const codepage & cp_from, const codepage & cp_to, Translator &trn, FILE *F)
+int WriteTranslator(const codepage & cp_from, const codepage & cp_to, Translator &trn, FILE *F)
 {
-WORD i,b,Max,EmptyBanks;
-char *cp_from_name,*cp_to_name;
+WORD i, b, Max, EmptyBanks;
+char *cp_from_name, *cp_to_name;
 char TranslatorType=0;
 long Banks[256];
 
- if(F==NULL) return;
+ if(F==NULL) return -1;
  if(trn.Data==NULL)
    {
-   printf("Error: Translator %s -> %s has not data!\n", cp_from.name, cp_to.name);
-   return;
+   printf("Error: Translator %s -> %s has no data!\n", cp_from.name, cp_to.name);
+   return -1;
    }
 
- printf("Info: Writing translator %s -> %s\n",cp_from.name,cp_to.name);
+ //printf("Info: Writing translator %s -> %s\n",cp_from.name,cp_to.name);
  Max = cp_from.MaxUsed;
  while(Max>0)
-    {
-    if(trn.Data[Max-1]!=0 && trn.Data[Max-1]!=0xFFFF) break;
-    Max--;
-    }
+   {
+   if(trn.Data[Max-1]!=0 && trn.Data[Max-1]!=0xFFFF) break;
+   Max--;
+   }
 
  cp_from_name=StrStr(cp_from.name,"/");
  if(cp_from_name==NULL) cp_from_name=cp_from.name;
@@ -463,7 +440,7 @@ long Banks[256];
              fprintf(F,"const WORD %s_%sB%d[]={",cp_from_name,cp_to_name,b);
              for(i=b*256;i<(b+1)*256;i++)
 		{
-		fprintf(F,"  %d%s",(i>=Max)?0:trn.Data[i],
+		fprintf(F,"  %d%s", (i>=Max)?0:trn.Data[i],
 			i==((b+1)*256-1)?"};":",");
 		if(i<Max)
 		  if(cp_from.characters[i]!=NULL && trn.Data[i]!=0)
@@ -491,7 +468,7 @@ long Banks[256];
              fprintf(F,"const BYTE %s_%sB%d[]={",cp_from_name,cp_to_name,b);
              for(i=b*256;i<(b+1)*256;i++)
 		{
-		fprintf(F,"  %d%s",(i>=Max)?0:trn.Data[i],
+		fprintf(F,"  %d%s", (i>=Max)?0:trn.Data[i],
 			i==((b+1)*256-1)?"};":",");
 		if(i<Max)
 		  if(cp_from.characters[i]!=NULL && trn.Data[i]!=0)
@@ -501,7 +478,7 @@ long Banks[256];
              }
         fputc('\n',F);     
         fprintf(F,"const BYTE *%s_%sB[]={",cp_from_name,cp_to_name);
-        for(b=0;b<=(Max-1)>>8;b++)
+        for(b=0; b<=(Max-1)>>8; b++)
   	     {
              if(Banks[b]==0) fprintf(F," NULL%s",(b==(Max-1)>>8)?"};":",");
                        else  fprintf(F," %s_%sB%d%s",cp_from_name,cp_to_name,(int)b,(b==(Max-1)>>8)?"};":",");
@@ -513,23 +490,50 @@ long Banks[256];
            cp_from_name,cp_to_name);
         break;
   }
+  return 0;
 }
 
 
+
+void Translator::erase(void)
+{
+  if(Data!=NULL) {free(Data);Data=NULL;}
+  ToCp = FromCp = NULL; 
+}
+
+
+codepage::~codepage(void)
+{
+  free(name);
+  free(characters);
+  Allocated = 0;
+};
+  
+
+
 /*This procedure displays errors that occured inside atoms unit*/
 #ifdef ERROR_HANDLER
-void RaiseError(int ErrNo, void *Instance)
+void RaiseError(int ErrNo, const void *Instance)
 {
 static int LastErrNo=0;
-static void *LastInstance=NULL;
+static const void *LastInstance=NULL;
 const char *UnitName="";
   //if(Verbosing<=-1) return;
   if(LastErrNo!=ErrNo || LastInstance!=Instance)
     {
-    if((ErrNo&0xFF00)==ListsId) UnitName=" Lists";
-    if((ErrNo&0xFF00)==StringsId) UnitName=" Strings";
+     switch(ErrNo >> 8)
+	{
+        case 1: UnitName="Strings"; break;	// StringsId = 0x100,
+        case 2: UnitName="Sets"; break;	// SetsId =    0x200,
+        case 3: UnitName="Lists"; break;	// ListsId =   0x300,
+        case 4: UnitName="Matrix"; break;	// MatrixId =  0x400,
+	case 5: UnitName="Stack"; break;	// StackId =   0x500,
+	case 6: UnitName="Interval"; break;	// IntervalId =0x600,
+	case 7: UnitName="Raster"; break;	// RasterId =  0x700,
+	case 8: UnitName="DblList"; break;	// DblListId = 0x800
+	}
     fprintf(stderr,"\nERROR: Internal inside ATOMS unit%s 0x%X object:(%p)",
-	UnitName,ErrNo,Instance);
+	UnitName, ErrNo, Instance);
     LastErrNo=ErrNo;LastInstance=Instance;
     }
 }
