@@ -261,6 +261,7 @@ const struct FmlTranslationArray FmlTransTable[] =
    { "PREC", "5", 0 },
    { "PROD", "5", 0 },
    { "REAL", "\\Re", 0 },
+   { "ROOT", " \\sqrt{1}", 0 },
    { "sinh", "5", 0 },
    { "SQRT", "5{1}", 0 },
    { "SUCC", "5", 0 },
@@ -1297,7 +1298,7 @@ bool MathArray = false;
  cq->envir = ' ';
  if(cq->line_term=='h') cq->char_on_line=true; //after HRt leave one row empty
  cq->line_term = 's';			/* Soft return */
- if(cq->char_on_line==true)
+ if(cq->char_on_line==CHAR_PRESENT)
 	{
 	NewLine(cq);
 	}
@@ -1554,21 +1555,21 @@ BYTE styles;
 		  }
 		if( (styles & AMSSYMB) != 0)
 		  {
-		  if(Amssymb>=false) {Amssymb=true; styles=0;}
+		  if(Amssymb>=STYLE_NOTUSED) {Amssymb=STYLE_USED; styles=0;}
 		  }
                 if( (styles & ACCENTS) != 0)
 		  {
-		  if(Accents>=false) {Accents=true; styles=0;}
+		  if(Accents>=STYLE_NOTUSED) {Accents=STYLE_USED; styles=0;}
 		  }
                 if((styles & SCALEREL) != 0)
 		  {
-		  if(Scalerel>=false) {Scalerel=true; styles=0;}
+		  if(Scalerel>=STYLE_NOTUSED) {Scalerel=STYLE_USED; styles=0;}
 		  }
 		if( (styles & LATEXSYM) != 0)
 		  {
 		  if ((LaTeX_Version & 0xFF00) >= 0x300)
 		    {
-		    if(LaTeXsym>=false) {LaTeXsym=true;styles=0;}
+		    if(LaTeXsym>=STYLE_NOTUSED) {LaTeXsym=STYLE_USED;styles=0;}
 		    }
 		  else styles=0;
 		  }
