@@ -286,6 +286,22 @@ TImageFileHandler HANDLER_##SUFFIX(EXTENSION,
 #endif
 
 
+#ifdef SupportRAS_SUN
+ ImplementReader(RAS_SUN, ".RAS")
+ #if SupportRAS_SUN>=4 || SupportRAS_SUN==2
+	LoadPictureRAS_SUN,
+ #else
+	NULL,
+ #endif
+ #if SupportRAS_SUN>=3
+ 	SavePictureRAS_SUN,
+ #else
+	NULL,
+ #endif
+        "SUN");
+#endif
+
+
 #ifdef SupportRAS
  ImplementReader(RAS,".RAS")
  #if SupportRAS>=4 || SupportRAS==2
@@ -302,22 +318,6 @@ TImageFileHandler HANDLER_##SUFFIX(EXTENSION,
 #endif
 
 
-#ifdef SupportRAS_SUN
- ImplementReader(RAS_SUN, ".RAS")
- #if SupportRAS_SUN>=4 || SupportRAS_SUN==2
-	LoadPictureRAS_SUN,
- #else
-	NULL,
- #endif
- //#if SupportRAS_SUN>=3
- //	SavePictureRAS_SUN);
- //#else
-	NULL,
- //#endif
-        "SUN");
-#endif
-
-
 #ifdef SupportRAW
   ImplementReader(RAW,".RAW")
 //#if SupportRAW>=4 || SupportRAW==2
