@@ -129,6 +129,21 @@ public: Raster1D_16Bit(int InitSize1D) {if((Data1D=malloc(2*InitSize1D))!=NULL)
 	};
 
 
+/*
+class Raster1D_16BitIDX: public Raster1D_16Bit
+{
+public: Raster1D_16BitIDX(int InitSize1D, Raster1DAbstractRGB *newPalette=NULL);
+        Raster1D_16BitIDX(void)	{pPalette=NULL;};
+        ~Raster1D_16BitIDX();
+
+        virtual int GetPlanes(void) const {return(-16);};
+        virtual void Set(const Raster1DAbstract &R1);
+
+        Raster1DAbstractRGB *pPalette;
+};
+*/
+
+
 /** 24 bit planes Gray */
 class Raster1D_24Bit:virtual public Raster1DAbstract
 	{
@@ -146,7 +161,7 @@ public: virtual int GetPlanes(void) const {return(24);};
 #endif
 	virtual void Get24BitRGB(void *Buffer24Bit) const;
 
-	virtual void Peel8Bit(BYTE *Buffer8Bit, char plane8);
+	virtual void Peel8Bit(BYTE *Buffer8Bit, char plane8) const;
 	virtual void Join8Bit(BYTE *Buffer8Bit, char plane8);
 	};
 
@@ -245,6 +260,18 @@ public: double Min, Max;
 };
 
 
+/*
+class Raster1D_5BitRGB: virtual public Raster1D_16Bit, virtual public Raster1DAbstractRGB
+{
+public:
+	unsigned R(unsigned x) const {return(((WORD*)Data1D)[x]&0x1F);}
+	unsigned G(unsigned x) const {return((((WORD*)Data1D)[x]>>5)&0x1F);}
+	unsigned B(unsigned x) const {return((((WORD*)Data1D)[x]>>10)&0x1F);}
+
+};
+*/
+
+
 /** 8 bit planes for 3 channels R,G,B */
 class Raster1D_8BitRGB: virtual public Raster1DAbstractRGB
 	{
@@ -254,6 +281,9 @@ public:	Raster1D_8BitRGB(int InitSize1D)  {Allocate1D(InitSize1D);};
 	virtual int GetPlanes(void) const {return(3*8);};
 	virtual unsigned GetSize1D(void) const {return(Size1D);};
 
+	virtual void Get(unsigned index, RGBQuad *RGB) const;
+	//virtual void Set(unsigned index, const RGBQuad *RGB);
+
 	virtual void Get24BitRGB(void *Buffer24Bit) const;
 
 	virtual DWORD GetValue1DRAW(unsigned x) const {if(x<3*Size1D) return(((BYTE *)Data1D)[x]); return(0);};
@@ -281,6 +311,11 @@ public:	Raster1D_16BitRGB(int InitSize1D)	{Allocate1D(InitSize1D);}
 	virtual unsigned GetSize1D(void) const {return(Size1D);};
 	virtual int GetPlanes(void) const {return(3*16);};
 
+	virtual void Get(unsigned index, RGBQuad *RGB) const;
+	//virtual void Set(unsigned index, const RGBQuad *RGB);
+
+	virtual void Get24BitRGB(void *Buffer24Bit) const;
+
         virtual DWORD GetValue1DRAW(unsigned x) const {if(x<3*Size1D) return(((WORD *)Data1D)[x]); return(0);};
 	virtual void SetValue1DRAW(unsigned x, DWORD NewValue) {if(x<3*Size1D) ((WORD *)Data1D)[x]=NewValue;};
 
