@@ -41,7 +41,7 @@ int NearAvailPlanes(int n)
   }
   if(n<=1) return(1);		// bit
   if(n<=2) return(2);
-  if(n<=4) return(4);
+  if(n<=4) return(4);		// nibble
   if(n<=8) return(8);		// byte
   if(n<=16) return(16);		// word
   if(n<=24) return(24);
@@ -90,8 +90,9 @@ void Raster1DAbstract::Cleanup(void)
 /** Push data to a given container. */
 void Raster1DAbstract::Get(Raster1DAbstract &R1) const
 {
-int i,maxi;
+int i, maxi;
 int shift;
+
  maxi = Size1D>R1.Size1D?Size1D:R1.Size1D;
 
  if(R1.GetPlanes()==GetPlanes())
@@ -303,12 +304,12 @@ BYTE *N_Buffer24Bit = (BYTE *)Buffer24Bit;
 /* Specialised Raster 1D modules */
 
 
-void Raster1DAbstract::Peel1Bit(void *Buffer1Bit, char plane)
+void Raster1DAbstract::Peel1Bit(void *Buffer1Bit, char plane) const
 {
 Raster1D_1Bit R1;
 int i,maxi;
 
- R1.Data1D=Buffer1Bit;R1.Size1D=Size1D;
+ R1.Data1D=Buffer1Bit; R1.Size1D=Size1D; R1.Shadow=true;
  maxi=Size1D>R1.Size1D?Size1D:R1.Size1D;
  for(i=0;i<maxi;i++)
 	{
@@ -317,13 +318,14 @@ int i,maxi;
  R1.Data1D=NULL;
 }
 
+
 void Raster1DAbstract::Join1Bit(void *Buffer1Bit, char plane)
 {
  Raster1D_1Bit R1;
  int i,maxi;
  long mask;
 
- R1.Data1D=Buffer1Bit;R1.Size1D=Size1D;
+ R1.Data1D=Buffer1Bit; R1.Size1D=Size1D; R1.Shadow=true;
  maxi=Size1D>R1.Size1D?Size1D:R1.Size1D;
 
  mask=~(1l<<plane);
@@ -343,13 +345,12 @@ void Raster1DAbstract::Join8Bit(BYTE *Buffer8Bit, char plane8)
  int i,maxi;
  long mask;
 
- R8.Data1D=Buffer8Bit;R8.Size1D=Size1D;
+ R8.Data1D=Buffer8Bit;R8.Size1D=Size1D; R8.Shadow=true;
  maxi=Size1D>R8.Size1D?Size1D:R8.Size1D;
  mask=~(0xFFl<<plane8);
 
  //printf("%d %lX %d;",plane8,mask,maxi);
-
- for(i=0;i<maxi;i++)
+ for(i=0; i<maxi; i++)
    {
    SetValue1D(i,(GetValue1D(i) & mask) | (R8.GetValue1D(i) << plane8));
    }
@@ -359,12 +360,11 @@ void Raster1DAbstract::Join8Bit(BYTE *Buffer8Bit, char plane8)
 
 /** Extracts 8 bit channel from raster data on given bit wise position.
  * Use 0,8,16 for RGB 8bit channels. */
-void Raster1DAbstract::Peel8Bit(BYTE *Buffer8Bit, char plane8)
+void Raster1DAbstract::Peel8Bit(BYTE *Buffer8Bit, char plane8) const
 {
 unsigned i;
 
- //printf("%d %lX %d;",plane8,mask,maxi);
- for(i=0;i<Size1D;i++)
+ for(i=0; i<Size1D; i++)
    {
    *Buffer8Bit++ = (GetValue1D(i)>>plane8) & 0xFF;
    }
@@ -926,6 +926,43 @@ signed char shift;
 
 #endif // OPTIMISE_SPEED
 
+
+/*
+Raster1D_16BitIDX::Raster1D_16BitIDX(int InitSize1D, Raster1DAbstractRGB *newPalette): Raster1D_16Bit(InitSize1D)
+{
+  pPalette = newPalette;
+  if(pPalette!=NULL)
+      pPalette->UsageCount++;
+}
+
+
+Raster1D_16BitIDX::~Raster1D_16BitIDX()
+{
+  if(pPalette!=NULL)
+  {
+    if(pPalette->UsageCount--<=1) delete(pPalette);
+    pPalette = NULL;
+  }
+}
+
+
+void Raster1D_16BitIDX::Set(const Raster1DAbstract &R1)
+{
+  if(pPalette!=NULL && R1.Channels()>=4 && Data1D!=NULL)
+  {
+    int maxi = Size1D>R1.Size1D?Size1D:R1.Size1D;
+    DWORD val;
+    while(maxi-- > 0)
+    {
+      val = GetValue1D(maxi);	// Indexed Val;
+      R1.SetValue1D(maxi,val);
+    }
+  }
+  else
+    Raster1D_16Bit::Set(R1);
+}
+*/
+
 /* ------------ 24 bit planes Gray ------------ */
 
 void Raster1D_24Bit::SetValue1D(unsigned x, DWORD NewValue)
@@ -1018,7 +1055,7 @@ void Raster1D_24Bit::Set(const Raster1DAbstract &R1)
 #endif // OPTIMISE_SPEED
 
 
-void Raster1D_24Bit::Peel8Bit(BYTE *Buffer8Bit, char plane8)
+void Raster1D_24Bit::Peel8Bit(BYTE *Buffer8Bit, char plane8) const
 {
 unsigned i;
 BYTE *b=(BYTE *)Data1D;
@@ -1031,7 +1068,7 @@ BYTE *b=(BYTE *)Data1D;
     {
     *(BYTE *)Buffer8Bit = *b;
 #ifdef NO_LVAL_CAST
-    Buffer8Bit=(BYTE *)Buffer8Bit + 1;
+    Buffer8Bit = (BYTE *)Buffer8Bit + 1;
 #else
     Buffer8Bit++;
 #endif
@@ -1443,24 +1480,27 @@ float MaxVal;
 
 /* ------------ 64 bit planes DOUBLE -------------- */
 
+/// Normalises value to the range 0 - 0xFFFFFFFF.
 DWORD Raster1D_64FltBit::GetValue1D(unsigned x) const
 {
   if(x>=Size1D) return 0;
-  return((((double *)Data1D)[x] - Min)*(Max-Min));
+  return(0xFFFFFFFF*(((double *)Data1D)[x] - Min)/(Max-Min));
 }
 
+void Raster1D_64FltBit::SetValue1D(unsigned x, DWORD NewValue)
+{
+  if(x>=Size1D) return;
+  ((double *)Data1D)[x] = Min + (double)NewValue*(Max-Min)/0xFFFFFFFF;
+  return;
+}
+
+
 double Raster1D_64FltBit::GetValue1Dd(unsigned x) const
 {
   if(x>=Size1D) return 0;
   return(((double *)Data1D)[x]);
 }
 
-void Raster1D_64FltBit::SetValue1D(unsigned x, DWORD NewValue)
-{
-  if(x>=Size1D) return;
-  ((double *)Data1D)[x] = Min + (double)NewValue/(Max-Min);
-  return;
-}
 
 void Raster1D_64FltBit::SetValue1Dd(unsigned x, double NewValue)
 {
@@ -1617,7 +1657,6 @@ void Raster1DAbstractRGB::Set(const Raster1DAbstract &R1)
 {
 int i,maxi;
 signed char shift;
-
 DWORD val;
 
   if(Data1D==NULL || R1.Data1D==NULL) return;
@@ -1631,24 +1670,24 @@ DWORD val;
     {
     switch(i)
       {
-      case 1: for(i=0;i<maxi;i++)	// convert from gray to RGB
+      case 1: while(maxi-- > 0)	// convert from gray to RGB
 		{
 		val = R1.GetValue1D(i);
-		R(i,val);
-		G(i,val);
-		B(i,val);
+		R(maxi,val);
+		G(maxi,val);
+		B(maxi,val);
 		}
 	      return;
 
       case 3: memcpy(Data1D, R1.Data1D, ((long)maxi*GetPlanes()+7)/8);   // convert from RGB to RGB - just copy
               return;
 
-      case 4: for(i=0;i<maxi;i++)	// convert from RGBA to RGB
+      case 4: while(maxi-- > 0)		// convert from RGBA to RGB
 		{
 		val = R1.GetValue1D(i);
-		R(i,val & 0xFF);
-		G(i,(val>>8)& 0xFF);
-		B(i,(val>>16)& 0xFF);
+		R(maxi,val & 0xFF);
+		G(maxi,(val>>8)& 0xFF);
+		B(maxi,(val>>16)& 0xFF);
 		}
 	      return;
       }
@@ -1656,30 +1695,70 @@ DWORD val;
 
   if(shift>0)
     {
-    for(i=0;i<maxi;i++)
+    while(maxi-- > 0)
        {
        val = R1.GetValue1D(i);
-       R(i,val<<shift);
-       G(i,val<<shift);
-       B(i,val<<shift);
+       val <<= shift;
+       R(maxi,val);
+       G(maxi,val);
+       B(maxi,val);
        }
     return;
     }
   else
     {
     shift = -shift;
-    for(i=0;i<maxi;i++)
+    while(maxi-- > 0)
      {
      val = R1.GetValue1D(i);
-     R(i,val>>shift);
-     G(i,val>>shift);
-     B(i,val>>shift);
+     val >>= shift;
+     R(maxi,val);
+     G(maxi,val);
+     B(maxi,val);
      }
     return;
     }
 }
 
 
+void Raster1DAbstractRGB::Set(const Raster1DAbstract &R1, const Raster1DAbstract &Palette)
+{
+int maxi;
+signed char shift = 0;
+DWORD val;
+
+  shift = GetPlanes()/Channels() - R1.GetPlanes()/R1.Channels();
+
+  maxi = Size1D>R1.Size1D?Size1D:R1.Size1D;
+
+  if(shift>0)
+    {
+    while(maxi-- > 0)
+      {
+      val = R1.GetValue1D(maxi);
+      val = Palette.GetValue1D(maxi);
+      R(maxi,val<<shift);
+      G(maxi,val<<shift);
+      B(maxi,val<<shift);
+      }
+    }
+  else
+    {
+    shift = -shift;
+    while(maxi-- > 0)
+      {
+      val = R1.GetValue1D(maxi);
+      val = Palette.GetValue1D(maxi);
+      R(maxi,val>>shift);
+      G(maxi,val>>shift);
+      B(maxi,val>>shift);
+      }
+
+    }
+}
+
+
+
 /** Copy data from a given container. */
 void Raster1DAbstractRGBA::Set(const Raster1DAbstract &R1)
 {
@@ -1725,6 +1804,24 @@ signed char shift;
 }
 
 
+void Raster1DAbstractRGB::Get(unsigned index, RGBQuad *RGB) const
+{
+ if(RGB==NULL) return;
+ RGB->R = R(index);
+ RGB->G = G(index);
+ RGB->B = B(index);
+}
+
+
+void Raster1DAbstractRGB::Set(unsigned index, const RGBQuad *RGB)
+{
+ if(RGB==NULL) return;
+ R(index, RGB->R);
+ G(index, RGB->G);
+ B(index, RGB->B);
+}
+
+
 /* 8 bit planes for 3 channels R,G,B */
 
 DWORD Raster1D_8BitRGB::GetValue1D(unsigned x) const
@@ -1752,6 +1849,19 @@ void Raster1D_8BitRGB::Get24BitRGB(void *Buffer24Bit) const
 }
 
 
+void Raster1D_8BitRGB::Get(unsigned index, RGBQuad *RGB) const
+{
+BYTE *ptrb;
+
+ if(RGB==NULL || Data1D==NULL || Size1D<index) return;
+ index *= 3; 
+ ptrb = ((BYTE *)Data1D)+index;
+ RGB->R = *ptrb++;
+ RGB->G = *ptrb++;
+ RGB->B = *ptrb;
+}
+
+
 #ifdef _REENTRANT
 
 DWORD Raster1D_8BitRGB::PTR_GetValue1D(const void *RAW_Data1D, unsigned x) const
@@ -1781,9 +1891,15 @@ DWORD Raster1D_16BitRGB::GetValue1D(unsigned x) const
 {
   if(x>=Size1D) return 0;
   x *= 6;
-  return((DWORD)((BYTE *)Data1D)[x+1] |
+#ifdef HI_ENDIAN
+  return((DWORD)((BYTE *)Data1D)[x+0] |
+        ((DWORD)((BYTE *)Data1D)[x+2])<<8 |
+        ((DWORD)((BYTE *)Data1D)[x+4])<<16);
+#else
+   return((DWORD)((BYTE *)Data1D)[x+1] |
         ((DWORD)((BYTE *)Data1D)[x+3])<<8 |
         ((DWORD)((BYTE *)Data1D)[x+5])<<16);
+#endif
 }
 
 
@@ -1799,15 +1915,38 @@ void Raster1D_16BitRGB::SetValue1D(unsigned x, DWORD NewValue)
 }
 
 
+void Raster1D_16BitRGB::Get24BitRGB(void *Buffer24Bit) const
+{
+  Conv16_8((unsigned char*)Buffer24Bit, (WORD*)Data1D, 3*Size1D);
+}
+
+void Raster1D_16BitRGB::Get(unsigned index, RGBQuad *RGB) const
+{
+WORD *ptrw;
+
+ if(RGB==NULL || Data1D==NULL || Size1D<index) return;
+ ptrw = (WORD*)(((BYTE *)Data1D)+6*index);
+ RGB->R = *ptrw++;
+ RGB->G = *ptrw++;
+ RGB->B = *ptrw++;
+}
+
+
 #ifdef _REENTRANT
 
 DWORD Raster1D_16BitRGB::PTR_GetValue1D(const void *RAW_Data1D, unsigned x) const
 {
   if(x>=Size1D) return 0;
   x *= 6;
+#ifdef HI_ENDIAN
+  return((DWORD)((BYTE *)RAW_Data1D)[x+0] |
+        ((DWORD)((BYTE *)RAW_Data1D)[x+2])<<8 |
+        ((DWORD)((BYTE *)RAW_Data1D)[x+4])<<16);
+#else
   return((DWORD)((BYTE *)RAW_Data1D)[x+1] |
         ((DWORD)((BYTE *)RAW_Data1D)[x+3])<<8 |
         ((DWORD)((BYTE *)RAW_Data1D)[x+5])<<16);
+#endif
 }
 
 void Raster1D_16BitRGB::PTR_SetValue1D(void *RAW_Data1D, unsigned x, DWORD NewValue) const
@@ -1870,10 +2009,17 @@ DWORD Raster1D_16BitRGBA::GetValue1D(unsigned x) const
 {
   if(x>=Size1D) return 0;
   x *= 8;
+#ifdef HI_ENDIAN
+  return((DWORD)((BYTE *)Data1D)[x+0] |
+	((DWORD)((BYTE *)Data1D)[x+2])<<8 |
+	((DWORD)((BYTE *)Data1D)[x+4])<<16 |
+	((DWORD)((BYTE *)Data1D)[x+6])<<24);
+#else
   return((DWORD)((BYTE *)Data1D)[x+1] |
 	((DWORD)((BYTE *)Data1D)[x+3])<<8 |
 	((DWORD)((BYTE *)Data1D)[x+5])<<16 |
 	((DWORD)((BYTE *)Data1D)[x+7])<<24);
+#endif
 }
 
 
@@ -2058,6 +2204,7 @@ unsigned i;
    if(Data1D==NULL)
      {
      Erase();
+     RaiseError(RasterId|No_Memory,this);
      return;
      }
    }
