@@ -49,6 +49,14 @@
 extern "C" {
 #endif
 
+#ifndef RGBQuad_DEFINED
+#define RGBQuad_DEFINED
+typedef struct
+	{
+	unsigned R,G,B,O;
+	} RGBQuad;
+#endif
+
 void Conv1_4(BYTE *Dest, const BYTE *Src, unsigned Size1D);
 void Conv1_8(BYTE *Dest, const BYTE *Src, unsigned Size1D);
 void Conv1_16(WORD *Dest, const BYTE *Src, unsigned Size1D);
@@ -126,7 +134,7 @@ int NearAvailPlanes(int n);
 class Raster1DAbstract
 {
 public: mutable short UsageCount;
-        bool Shadow;
+	bool Shadow;			// The data are not allocated/deallocated with this object.
 	unsigned Size1D;
 	void *Data1D;
 
@@ -143,24 +151,24 @@ public: mutable short UsageCount;
 	virtual double GetValue1Dd(unsigned x) const {return(GetValue1D(x));};
 	virtual void SetValue1D(unsigned x, DWORD NewValue) ABSTRACT_ERROR("SetValue1D");
 	virtual void SetValue1Dd(unsigned x, double NewValue) {SetValue1D(x,(DWORD)NewValue);};
+	virtual void Get(unsigned x, RGBQuad *RGB) const {RGB->R=RGB->G=RGB->B=GetValue1D(x);};
 
 	virtual int GetPlanes(void) const {return(0);};
 	virtual unsigned GetSize1D(void) const {return(Size1D);};
-        virtual char Channels(void) const {return 1;};
+	virtual char Channels(void) const {return 1;};
 	void *GetRow(void)          {return(Data1D);};
 
 /* This set of functions copy internal data in the proper format to the given buffer. */
 	virtual void Get(Raster1DAbstract &R1) const;
-
 	virtual void Get24BitRGB(void *Buffer24Bit) const;
 
 /* This set of functions receives given data and stores them to the internal structure. */
 	virtual void Set(const Raster1DAbstract &R1);
 
 /* Bitwise operation with raster buffer. */
-	virtual void Peel1Bit(void *Buffer1Bit, char plane);
+	virtual void Peel1Bit(void *Buffer1Bit, char plane) const;
 	virtual void Join1Bit(void *Buffer1Bit, char plane);
-	virtual void Peel8Bit(BYTE *Buffer8Bit, char plane8);
+	virtual void Peel8Bit(BYTE *Buffer8Bit, char plane8) const;
 	virtual void Join8Bit(BYTE *Buffer8Bit, char plane8);
 
 	virtual Raster1DAbstract *GetPalette(void) {return(NULL);}
@@ -190,6 +198,10 @@ public:
   virtual char Channels(void) const {return 3;};
 
   virtual void Set(const Raster1DAbstract &R1);
+  virtual void Set(const Raster1DAbstract &R1, const Raster1DAbstract &Palette);
+
+  virtual void Get(unsigned index, RGBQuad *RGB) const;
+  virtual void Set(unsigned index, const RGBQuad *RGB);
 
   unsigned R(unsigned x) const {return(GetValue1DRAW(3*x));}
   unsigned G(unsigned x) const {return(GetValue1DRAW(3*x+1));}
@@ -272,7 +284,7 @@ public: unsigned Size2D;
 
 	friend Raster2DAbstract *CreateRaster2D(unsigned Size1D, unsigned Size2D, int Planes);
 
-        RASTER_2D_VIRTUALS        
+        RASTER_2D_VIRTUALS
 
 protected:
 	void Erase2DStub(void);
@@ -389,7 +401,7 @@ void Flip3D(Raster3DAbstract *r3D);
 
 /* ---------- Global class Image --------- */
 
-#define RAS_IMG_VERSION (0x200 | 57)
+#define RAS_IMG_VERSION (0x200 | 58)
 
 /*Definition of errors while Loading/Saving File(s)*/
 #define ErrOK		  0
@@ -422,9 +434,7 @@ struct RGB_Record
 
 class APalette: virtual public Raster1DAbstractRGB
 	{
-public: virtual void Get(unsigned index, RGBQuad *RGB) const;
-        virtual void Set(unsigned index, const RGBQuad *RGB);
-	friend APalette *BuildPalette(unsigned Indices, char type);
+public: friend APalette *BuildPalette(unsigned Indices, char type);
 
         virtual void SetPalette(Raster1DAbstract *NewPalette) {AbstractError("APalette::SetPalette");}
 	};
@@ -497,7 +507,7 @@ void Flip1D(Raster2DAbstract *r2D);
 void Flip2D(Raster2DAbstract *r2D);
 int ReducePalette(Image *Img, unsigned maxColors);
 int GrayPalette(APalette *Palette, int Planes=0);
-int FillGray(Raster1DAbstractRGB *Palette,int Planes);
+int FillGray(Raster1DAbstractRGB *Palette, int Planes=0);
 
 
 typedef struct
