@@ -215,19 +215,21 @@ DWORD Image::GetPixelRGB(unsigned Offset1D, unsigned Offset2D) const
 	     return Raster->GetValue2D(Offset1D,Offset2D);
     case ImagePalette:
 	     {
-	     DWORD b = Raster->GetValue2D(Offset1D,Offset2D);
+	     const DWORD b = Raster->GetValue2D(Offset1D,Offset2D);
 	     return Palette->GetValue1D(b);
 	     }
     default: {
-	     DWORD b=Raster->GetValue2D(Offset1D,Offset2D);
+	     DWORD b = Raster->GetValue2D(Offset1D,Offset2D);
 	     switch(Raster->GetPlanes())
 	     {
-	       case  1: b *= 0xFF; break;
-	       case  2: b *= 85; break;		// 255/3 = 85  -> 85*3=0xFF
-	       case  4: b *= 17; break;		// 255/15=17   -> 17*15=0xFF
-	       case 16: b >>= 8; break;
-	       case 24: b >>= 16; break;
-	       case 32: b >>= 24; break;
+	       case   1: b *= 0xFF; break;
+	       case   2: b *= 85; break;		// 255/3 = 85  -> 85*3=0xFF
+	       case   4: b *= 17; break;		// 255/15=17   -> 17*15=0xFF
+	       case  16: b >>= 8; break;
+	       case  24: b >>= 16; break;
+	       case  32:
+	       case -32:				// floats are normalised to the full range 0 ... 0xFFFFFFFF.
+	       case -64: b>>=24; break;
 	     }
 	     return b | 0x100*b | 0x10000*b;
 	     }
@@ -575,66 +577,18 @@ void Flip3D(Raster3DAbstract *r3D)
 //////////////////////////////////////////////////////////
 
 
-
 class Palette_8bit: virtual public APalette, virtual public Raster1D_8BitRGB
 	{
 public:	Palette_8bit(int Indices): Raster1D_8BitRGB(Indices) {};
 	Palette_8bit(void): Raster1D_8BitRGB() {};
-
-	virtual void Get(unsigned index, RGBQuad *RGB) const;
 	};
 
 class Palette_16bit: virtual public APalette, virtual public Raster1D_16BitRGB
 	{
 public:	Palette_16bit(int Indices): Raster1D_16BitRGB(Indices) {};
 	Palette_16bit(void) {};
-
-	virtual void Get(unsigned index, RGBQuad *RGB) const;
 	};
 
-void Palette_8bit::Get(unsigned index, RGBQuad *RGB) const
-{
-BYTE *ptrb;
-
- if(RGB==NULL || Data1D==NULL || Size1D<index) return;
- index *= 3; 
- ptrb = ((BYTE *)Data1D)+index;
- RGB->R = *ptrb++;
- RGB->G = *ptrb++;
- RGB->B = *ptrb;
-}
-
-
-void Palette_16bit::Get(unsigned index, RGBQuad *RGB) const
-{
-BYTE *ptrb;
-
- if(RGB==NULL || Data1D==NULL || Size1D<index) return;
- index *= 6; 
- ptrb = ((BYTE *)Data1D)+index;
- RGB->R = *(WORD*)ptrb;		ptrb += 2;
- RGB->G = *(WORD*)ptrb;		ptrb += 2;
- RGB->B = *(WORD*)ptrb;
-}
-
-
-void APalette::Get(unsigned index, RGBQuad *RGB) const
-{
- if(RGB==NULL) return;
- RGB->R = R(index);
- RGB->G = G(index);
- RGB->B = B(index);
-}
-
-
-void APalette::Set(unsigned index, const RGBQuad *RGB)
-{
- if(RGB==NULL) return;
- R(index, RGB->R);
- G(index, RGB->G);
- B(index, RGB->B);
-}
-
 
 APalette *BuildPalette(unsigned Indices, char type)
 {
@@ -693,7 +647,9 @@ unsigned PalItems;
 }
 
 
-/** Make this palette gray. */
+/** Make this palette gray.
+ * @param[in,out]	Palette	Palette to be set as gray.
+ * @param[in]		Planes	If nonzeto, check for real planes per channel. */
 int FillGray(Raster1DAbstractRGB *Palette, int Planes)
 {
 unsigned i;
