@@ -343,7 +343,7 @@ void Attr_OFF(TconvertedPass1 *cq, unsigned char b)
      fread(&b, sizeof(unsigned char), 1, cq->wpd);   /* less attribuut-code */
   b &= 0x7F;			// mask bit 7: nested duplicated attr
 
-  if(b==0xA && colors<=false) goto RejectAttr;
+  if(b==0xA && colors<=0) goto RejectAttr;
   if ((b==7) && ((LaTeX_Version & 0xFF00) < 0x300))  goto RejectAttr;
 
   _AttrOff(cq->attr,b & 0xF,s);
@@ -442,7 +442,7 @@ void Column(TconvertedPass1 *cq, signed char number)
 int i;
 const char b='M';
 
- if(Columns<false)
+ if(Columns<0)
 	{
 	strcpy(cq->ObjType, "!Col");
 	return;
@@ -451,7 +451,7 @@ const char b='M';
 			/* Any of section's attr cannot be opened */
  for(i=First_com_section; i<=Last_com_section; i++)
 		     AttrOff(cq,i);
- if(cq->char_on_line==true) NewLine(cq);
+ if(cq->char_on_line==CHAR_PRESENT) NewLine(cq);
 
  if(number>1)
 	 {
@@ -611,16 +611,16 @@ void LineNumbering(TconvertedPass1 *cq, BYTE LineNumbering)
 
   if(LineNumbering)
     {
-    if(LineNo>=false) 
+    if(LineNo>=STYLE_NOTUSED) 
       {
-      LineNo = true;    
+      LineNo = STYLE_USED;
       AttrOn(cq->attr,Line_Num);
       }
     }
   else
     AttrOff(cq,Line_Num);
 
-sprintf(cq->ObjType,"%sLine Num:%s", (LineNo>=0)?"":"!", (LineNumbering&1)?"On":"Off");
+sprintf(cq->ObjType,"%sLine Num:%s", (LineNo>=STYLE_NOTUSED)?"":"!", (LineNumbering&1)?"On":"Off");
 }
 
 
@@ -814,14 +814,14 @@ void CellTable(TconvertedPass1 *cq)
 
   if(cq->envir == 'B')
        {
-       if(cq->char_on_line==true || cq->char_on_line==-1)
+       if(cq->char_on_line==CHAR_PRESENT || cq->char_on_line==-1)
 	 {
 	 Close_All_Attr(cq->attr,cq->strip);
 	 fprintf(cq->strip, " & ");
 	 }
        cq->char_on_line = true;
        }
-  else if(cq->char_on_line==true) fputc(' ',cq->strip);
+  else if(cq->char_on_line==CHAR_PRESENT) fputc(' ',cq->strip);
 
   strcpy(cq->ObjType, "!Cell"+((cq->envir!='B')?0:1));
 }
@@ -835,7 +835,7 @@ void Center(TconvertedPass1 *cq)
   fprintf(cq->log,"\n#Center() ");fflush(cq->log);
 #endif
 
-  if(cq->char_on_line == -10)	/* first line of minipages */
+  if(cq->char_on_line == FIRST_CHAR_MINIPAGE)  /* first line of minipages */
 	{			/* a new line have to be creared */
 	fputs("%\n", cq->strip);
 	cq->line_term = 's';   /* Soft return */
@@ -845,14 +845,14 @@ void Center(TconvertedPass1 *cq)
 
 	cq->nomore_valid_tabs = false;
 	Make_tableentry_attr(cq);
-	cq->char_on_line = false;
+	cq->char_on_line = NO_CHAR;
 	}
 
   if (cq->envir == ' ')		/* environment = center */
 	{
 	cq->envir = 'c';	// the small 'c' is turned off on by the EOL
-	if(cq->char_on_line != true)
-		cq->char_on_line = -20;
+	if(cq->char_on_line != CHAR_PRESENT)
+		cq->char_on_line = LEAVE_ONE_EMPTY_LINE;
 	}
 
   strcpy(cq->ObjType, "Center");
@@ -973,7 +973,7 @@ void Color(TconvertedPass1 *cq, signed char WP, RGBQuad *RGB)
 const char *ColorType="?";
 BYTE Red,Green,Blue;
 
-  if(colors<false || LaTeX_Version<0x300)
+  if(colors<0 || LaTeX_Version<0x300)
 	{
 	strcpy(cq->ObjType, "!Color");
 	return;
@@ -1119,7 +1119,7 @@ void Flush_right(TconvertedPass1 *cq,char type)
 //    cq->envir = 'T';
       }
       else {
-	   if(cq->char_on_line!=true) fprintf(cq->strip, "\\strut");
+	   if(cq->char_on_line!=CHAR_PRESENT) fprintf(cq->strip, "\\strut");
 	   cq->char_on_line = true;   /*Something is placed on line */
 	   if(type==1) fprintf(cq->strip, "\\dotfill ");
 		  else fprintf(cq->strip, "\\hfill ");
@@ -1339,7 +1339,7 @@ void InvisibleSoftReturn(TconvertedPass1 *cq)
   fprintf(cq->log,"\n#InvisibleSoftReturn() ");fflush(cq->log);
 #endif
 
-  if(cq->char_on_line==true) /* Ignore misplaced ISRt */
+  if(cq->char_on_line==CHAR_PRESENT) /* Ignore misplaced ISRt */
      {
      fprintf(cq->strip, "{\\penalty0}");
      }
@@ -1368,15 +1368,15 @@ static const char JustWP3_2WP5[4]={0,2,3,1};
   if((WPx==3 || WPx==1)  && (b&0xFC)==0)
 	  b=JustWP3_2WP5[b&0x3];
 
-  if(cq->char_on_line == -10)	//first line after minipages
-	{
-	putc('%', cq->strip);
-	cq->char_on_line=true;
-	}
-  if(cq->char_on_line==true)                      //!!!!!!!!!   ////
-     {
-     NewLine(cq);
-     }
+  if(cq->char_on_line == FIRST_CHAR_MINIPAGE)	//first line after minipages
+    {
+    putc('%', cq->strip);
+    cq->char_on_line = CHAR_PRESENT;
+    }
+  if(cq->char_on_line==CHAR_PRESENT)                      //!!!!!!!!!   ////
+    {
+    NewLine(cq);
+    }
   cq->latex_tabpos = 0;
   OldEnvir = cq->envir;
   cq->envir = ' ';
@@ -1409,7 +1409,7 @@ static const char JustWP3_2WP5[4]={0,2,3,1};
     {
     //Close_All_Attr(cq->attr,cq->strip); Not required! Attributes are handled in pass2.
     if(cq->envir!=' ' || OldEnvir!=' ')
-  	cq->char_on_line = -20;
+  	cq->char_on_line = LEAVE_ONE_EMPTY_LINE;
     }
 
 JustifEnd:
@@ -1524,9 +1524,9 @@ int i;
       {
       if(CurLang[0] == LangTable[i].WP3LangId)
         {
-        if(LangTable[i].UseLang>=false)
+        if(LangTable[i].UseLang >= 0)
 	  {
-	  LangTable[i].UseLang = true;
+	  LangTable[i].UseLang = 1;
 	  LangStr = LangTable[i].LangDesc;
 	  }
         break;
@@ -1539,9 +1539,9 @@ int i;
       {
       if(!strncmp(CurLang,LangTable[i].LangShort,2))
         {
-        if(LangTable[i].UseLang>=false)
+        if(LangTable[i].UseLang >= 0)
 	  {
-	  LangTable[i].UseLang = true;
+	  LangTable[i].UseLang = 1;
 	  LangStr = LangTable[i].LangDesc;
 	  }
         break;
@@ -1764,7 +1764,7 @@ void PlaceIndex(TconvertedPass1 *cq)
   Index=true;
   cq->line_term = 's';   		/* Soft return */
   if(cq->char_on_line) NewLine(cq);
-  if(MakeIdx>=false) MakeIdx=true;
+  if(MakeIdx>=0) MakeIdx=1;
   fprintf(cq->strip, "\\printindex	%%here should be placed index");
   NewLine(cq);
   strcpy(cq->ObjType, "Def Mark:Index");
@@ -1780,7 +1780,7 @@ void RowTable(TconvertedPass1 *cq, char LineType)
 
   if(cq->envir == 'B')
        {
-       if(cq->char_on_line==true || cq->char_on_line==-1)
+       if(cq->char_on_line==CHAR_PRESENT || cq->char_on_line==JUNK_CHARS)
 	 {
 	 Close_All_Attr(cq->attr,cq->strip);
 	 fprintf(cq->strip, " \\\\");
@@ -2250,12 +2250,12 @@ const char *TabType="";
 		}
         }
 
-    if ((cq->char_on_line<=false) && cq->envir != 'T')
+    if ((cq->char_on_line<=NO_CHAR) && cq->envir != 'T')
         {
         if(new_tabs==0) new_tabs++;
         for (j = 1; j <= new_tabs; j++)
 	        fprintf(cq->strip, "\\TAB ");
-	cq->char_on_line = true;
+	cq->char_on_line = CHAR_PRESENT;
         new_tabs = 0;
 	}
 
@@ -2294,7 +2294,7 @@ void TableOfContents(TconvertedPass1 *cq, char WP)
   char ListType,ListSubType,b;
   string ListName;
 
-  if ((cq->char_on_line==true)||(cq->attr.Opened_Depth>0))
+  if ((cq->char_on_line==CHAR_PRESENT)||(cq->attr.Opened_Depth>0))
     {
     Close_All_Attr(cq->attr,cq->strip);
 
@@ -2388,9 +2388,9 @@ void Terminate_Line(TconvertedPass1 *cq, char line_term)
 	    cq->envir != 'I' && cq->envir != 'i' && cq->envir != 'B')
 		{	// turn off one line long enviroments
 		if( (cq->envir == 'c' || cq->envir == 'T')
-		     && cq->char_on_line == true)
+		     && cq->char_on_line == CHAR_PRESENT)
 			{
-			cq->char_on_line = -20;
+			cq->char_on_line = LEAVE_ONE_EMPTY_LINE;
 			cq->envir = ' ';
 			goto NoSetCharOnLine;
 			}
@@ -2463,6 +2463,25 @@ void TconvertedPass1::InitMe(FILE *FileIn, FILE *Table, FILE *StripOut, FILE *Lo
 }
 
 
+#ifndef __Limited_Proc_Size
+void TconvertedPass1::PleaseReport(const char *Feature, const char *Type)
+{
+static const char *PrevFeature = NULL;
+  if(err==NULL) return;
+
+  if(PrevFeature != NULL)  
+  {
+    if(!strcmp(PrevFeature,Feature)) return;
+  }
+  PrevFeature = Feature;
+
+  perc.Hide();
+  fprintf(err, _("\nNote: Please send me this %s file for WP2LaTeX improvment, unimplemented feature \"%s\"."),Type,Feature);
+}
+#endif
+
+
+
 void ReportNoMemory(TconvertedPass1 *cq)
 {
   fprintf((cq==NULL||cq->err==NULL)?stderr:cq->err, _("\nFatal: Not enough memory."));
