@@ -2119,7 +2119,7 @@ DWORD fsize;
 
   DocumentStart=ftell(wpd);
 
-  fsize=filesize(wpd);
+  fsize = FileSize(wpd);
   perc.Init(ftell(wpd), fsize, _("First pass WP 5.x:") );
 
   if(DocumentStart>0x10)	//This can be omitted
