@@ -13,6 +13,7 @@
 #include "wp2latex.h"
 #include "struct.h"
 
+
 #if defined(__UNIX__)||defined(__DJGPP__)
  #include <unistd.h>
 #endif
@@ -79,8 +80,8 @@ WORD idx;                     /* index into buffer */
 WORD pidx;                    /* index down password */
 BYTE xmask;                   /* XOR mask */
 DWORD len;
-DWORD pos=ftell(Encrypted);
-DWORD fsize=filesize(Encrypted);
+DWORD pos = ftell(Encrypted);
+DWORD fsize = FileSize(Encrypted);
 
  if(ErrorFile==NULL) ErrorFile=stderr;
  if((buf=(char *)malloc(4096))==NULL) return;
@@ -89,14 +90,14 @@ DWORD fsize=filesize(Encrypted);
  pidx = 0;                      /* start of password */
  xmask = length(PassWord)+1;	/* start at password length+1 */
 
- if (Verbosing >= 1) printf(_("\nDecrypting ...\n\n"));
+ if(Verbosing >= 1) printf(_("\nDecrypting ...\n\n"));
 
- while( pos<fsize )
+ while(pos<fsize)
 	 {
-	 if( fsize-pos > 4096 ) len = 4096;
-			   else len = fsize-pos;
+	 if(fsize-pos > 4096) len = 4096;
+			 else len = fsize-pos;
 
-	 if( fread( buf, 1, len, Encrypted ) !=len )
+	 if(fread( buf, 1, len, Encrypted ) !=len)
 		 {
 		 fprintf(ErrorFile,_("\nError: Unexpected end of the input file."));
 		 break;
@@ -108,9 +109,9 @@ DWORD fsize=filesize(Encrypted);
 		 if( pidx == length(PassWord) ) pidx = 0;
 		 }
 
-	   if( Decrypted )
+	   if(Decrypted)
 		 {
-		 if( fwrite( buf, 1, len, Decrypted ) !=len )
+		 if(fwrite( buf, 1, len, Decrypted ) !=len)
 			 {
 			 fprintf(ErrorFile,_("\nError: Couldn't write %lu bytes to the temporary file.\n"), (long unsigned)len);
 			 break;
@@ -132,19 +133,19 @@ int TconvertedPass1_xWP5::Convert_first_pass(void)
 WORD encryption;
 string temp_filename;
 DWORD DocumentStart;	/* position in file */
-FILE *DecryptedFile=NULL;
+FILE *DecryptedFile = NULL;
 BYTE SmallBuf[16];
 TconvertedPass1 *cqPass1;
 int RetVal=0;
 
-  cqPass1=GetConverter("WP5.x");
+  cqPass1 = GetConverter("WP5.x");
   if(cqPass1==NULL)
 	{
 	RunError(0x202,"WP5.x");  /* unsupported module wp5 */
 	return(-1);
 	}
 
-  DocumentStart=ftell(wpd);
+  DocumentStart = ftell(wpd);
   fseek(wpd,12,SEEK_SET);	//check for encrypted documents
 
   RdWORD_HiEnd(&encryption, wpd);
@@ -218,7 +219,7 @@ BYTE SmallBuf[16];
 TconvertedPass1 *cqPass1;
 int RetVal=0;
 
-  cqPass1=GetConverter("WP3.x");
+  cqPass1 = GetConverter("WP3.x");
   if(cqPass1==NULL)
 	{
 	RunError(0x202,"WP3.x");  /* unsupported module wp3 */
