@@ -27,6 +27,7 @@
 #include "wp2latex.h"
 #include "struct.h"
 #include "images/raster.h"
+#include "images/img_futi.h"
 
 #ifdef __BORLANDC__
  #include "cp_lib/cptran.h"
@@ -553,7 +554,7 @@ NoHTML:
 /// This procedure provides autodetection of MTEF format.
 static int DetectMTEF(FILE *stream, FFormatDetect & iFFD)
 {
-DWORD Version,ObjLen,FileSize;
+DWORD Version,ObjLen,ThisFileSize;
 WORD HdrLen;
 
   iFFD.DocumentType = "MTEF";
@@ -561,7 +562,7 @@ WORD HdrLen;
   iFFD.Extension = "MTF";
   if(stream==NULL) return(0);
 
-  FileSize=filesize(stream);
+  ThisFileSize = FileSize(stream);
   fseek(stream,0,SEEK_SET);
   Rd_word(stream, &HdrLen);
   Rd_dword(stream, &Version);
@@ -572,7 +573,7 @@ WORD HdrLen;
   fseek(stream,8,SEEK_SET);
   Rd_dword(stream, &ObjLen);
 
-  if(ObjLen+HdrLen!=FileSize) goto NoMTEF;	//wrong overall size
+  if(ObjLen+HdrLen!=ThisFileSize) goto NoMTEF;	//wrong overall size
 
   fseek(stream,HdrLen+3,SEEK_SET);
   RdWORD_HiEnd((WORD *)&iFFD.DocVersion,stream);
@@ -935,12 +936,12 @@ DWORD cbMac=0xFFFF;
 	    Rd_dword(f,&cbMac);
 	    if(feof(f))
 		{fseek(f,CurrentPos,SEEK_SET);return(0);}
-	    if(cbMac==filesize(f))
+	    if(cbMac==FileSize(f))
 		{
 		fseek(f,CurrentPos,SEEK_SET);
 		return(8);
 		}
-	    cbMac=filesize(f);
+	    cbMac=FileSize(f);
 	    break;
      }
 
