@@ -166,10 +166,10 @@ char c;
 
 /// This procedure displays errors that occured inside atoms unit
 #ifdef ERROR_HANDLER
-void RaiseError(int ErrNo,void *Instance)
+void RaiseError(int ErrNo, const void *Instance)
 {
 static int LastErrNo=0;
-static void *LastInstance=NULL;
+static const void *LastInstance=NULL;
 const char *UnitName="";
   if(Verbosing<=-1) return;
   if(LastErrNo!=ErrNo || LastInstance!=Instance)
