@@ -17,8 +17,8 @@
 
 #define LineLength   80		/* Split lines after more than LineLength charcters */
 
-#define VersionWP2L	"3.110"
-#define VersionDate	"7 Nov 2022"  /* day (space) month (space) full year */
+#define VersionWP2L	"3.111"
+#define VersionDate	"1 Dec 2022"  /* day (space) month (space) full year */
 
 
 /* Constants for a flag InputPS */
@@ -547,16 +547,6 @@ typedef struct
 extern const TOutCodePage OutCodepages[11];
 
 
-#ifndef __Have_stricmp
- #ifdef __Have_strcasecmp
-  #define stricmp strcasecmp
- #endif
- #ifndef stricmp        //already fixed?
-  #define stricmp strcmp
- #endif
-#endif
-
-
 #ifndef FINAL
 void CrackObject(TconvertedPass1 *cq, DWORD end_of_code);
 #endif
